@@ -22,7 +22,7 @@ class Distinct(Selectable):
 
 
 class DistinctOn(Selectable):
-    def __init__(self, distinct_on_columns: list[Column], selectables: list[Selectable]):
+    def __init__(self, distinct_on_columns: list[Column]):
         if len(distinct_on_columns) != 1:
             raise NotImplementedError("DistinctOn working only with one column")
         # TODO problem is that we need column.clickhouse_type to cast CH response;
@@ -30,9 +30,7 @@ class DistinctOn(Selectable):
         column = first(distinct_on_columns)
         super(DistinctOn, self).__init__(column.clickhouse_type, nullable=False, name=f"{column.name}_distinct_on")
         self.column=column
-        self.selectables = selectables
 
     def to_selector(self) -> str:
-         return f"distinct on({self.column.name}) " \
-                f"{', '.join(selectable.to_selector() for selectable in self.selectables)}"
+         return f"distinct on({self.column.name})"
 
